@@ -25,7 +25,7 @@ LZMA_compress(__attribute__((unused)) PyObject *self, PyObject *args, PyObject *
 	lzma_ret lzuerror;
 	lzma_stream _lzus;
 	lzma_stream *lzus = &_lzus;
-	lzma_options_alone alone;
+	lzma_options_lzma options;
 	bool eopm = false;
 	if(kwargs != NULL){
 		PyObject* eopmString = PyString_FromString("eopm");
@@ -38,22 +38,23 @@ LZMA_compress(__attribute__((unused)) PyObject *self, PyObject *args, PyObject *
 	if (!PyArg_ParseTuple(args, "s#:compress", &input, &length))
 		return NULL;
 
-	alone.lzma = lzma_preset_lzma[LZMA_DEFAULT_COMPRESSION-1];
+	lzma_lzma_preset(&options, LZMA_DEFAULT_COMPRESSION-1);
 	if(PyDict_Size(kwargs) >= 0)
-		if(!init_lzma_options("compress", kwargs, &alone.lzma))
+		if(!init_lzma_options("compress", kwargs, &options))
 			return NULL;
 
-	*lzus = LZMA_STREAM_INIT_VAR;
+	lzma_stream tmp = LZMA_STREAM_INIT;
+	*lzus = tmp;
 	bufsize = length + (length/100+1) + 600;
 
 	if (!(RetVal = PyString_FromStringAndSize(NULL, bufsize)))
 		return NULL;
-	if(eopm)
-		alone.uncompressed_size = LZMA_VLI_VALUE_UNKNOWN;
+/*	if(eopm)
+		options.uncompressed_size = LZMA_VLI_VALUE_UNKNOWN;
 	else
-		alone.uncompressed_size = (uint64_t)length;
-
-	lzuerror = lzma_alone_encoder(lzus, &alone);
+		options.uncompressed_size = (uint64_t)length;
+*/
+	lzuerror = lzma_alone_encoder(lzus, &options);
 	if(!Util_CatchLZMAError(lzuerror, lzus))
 		goto error;
 
@@ -104,7 +105,8 @@ LZMA_decompress(__attribute__((unused)) PyObject *self, PyObject *args)
 	if (r_strlen <= 0)
 		r_strlen = 1;
 
-	*lzus = LZMA_STREAM_INIT_VAR;
+	lzma_stream tmp = LZMA_STREAM_INIT;
+	*lzus = tmp;
 	lzus->avail_in = (size_t)length;
 	lzus->avail_out = (size_t)r_strlen;
 	if (!(result_str = PyString_FromStringAndSize(NULL, r_strlen)))
@@ -112,7 +114,7 @@ LZMA_decompress(__attribute__((unused)) PyObject *self, PyObject *args)
 
 	lzus->next_out =  (uint8_t *)PyString_AS_STRING(result_str);
 	lzus->next_in = (uint8_t *)input;
-	lzuerror = lzma_auto_decoder(lzus, 0, 0);
+	lzuerror = lzma_auto_decoder(lzus, -1, 0);
 
 	if(!Util_CatchLZMAError(lzuerror, lzus))
 		goto error;
