@@ -8,7 +8,7 @@ typedef struct
 {
 	PyObject_HEAD
 	lzma_stream lzus;
-	lzma_options_alone alone;
+	lzma_options_lzma options;
 	bool is_initialised, running;
 	PyObject *lzma_options;
 #ifdef WITH_THREAD
