@@ -155,7 +155,8 @@ static PyObject * LZMADecomp_flush(LZMADecompObject *self, PyObject *args)
 	if (!(RetVal = PyString_FromStringAndSize(NULL, length)))
 		goto error;
 
-	*lzus = LZMA_STREAM_INIT_VAR;
+	lzma_stream tmp = LZMA_STREAM_INIT;
+	*lzus = tmp;
 
 	start_total_out = lzus->total_out;
 	lzus->avail_out = (size_t)length;
@@ -230,7 +231,7 @@ LZMADecomp_reset(LZMADecompObject *self, PyObject *args)
 	if((self->unconsumed_tail = PyString_FromString("")) == NULL)
 		goto error;
 
-	lzuerror = lzma_auto_decoder(lzus, 0, 0);
+	lzuerror = lzma_auto_decoder(lzus, -1, 0);
 	if(!Util_CatchLZMAError(lzuerror, lzus))
 		goto error;
 	self->running = true;
@@ -274,7 +275,8 @@ LZMADecompObject_new(PyTypeObject *type, __attribute__((unused)) PyObject *args,
 				goto error;
 		if((self->unconsumed_tail = PyString_FromString("")) == NULL)
 			goto error;
-		self->lzus = LZMA_STREAM_INIT_VAR;
+		lzma_stream tmp = LZMA_STREAM_INIT;
+		self->lzus = tmp;
 	}
 	else
 		return NULL;
@@ -321,7 +323,7 @@ LZMADecomp_init(LZMADecompObject *self, PyObject *args)
 		goto error;
 	}
 
-	lzuerror = lzma_auto_decoder(lzus, 0, 0);
+	lzuerror = lzma_auto_decoder(lzus, -1, 0);
 	if(!Util_CatchLZMAError(lzuerror, lzus))
 		goto error;
 
