@@ -316,7 +316,7 @@ LZMAFile_write(LZMAFileObject *self, PyObject *args)
 	PyObject *ret = NULL;
 	char *buf;
 	int len;
-	int lzuerror;
+	lzma_ret lzuerror;
 
 	if (!PyArg_ParseTuple(args, "s#:write", &buf, &len))
 		return NULL;
@@ -373,7 +373,7 @@ LZMAFile_writelines(LZMAFileObject *self, PyObject *seq)
 	PyObject *ret = NULL;
 	PyObject *line;
 	int i, j, index, len, islist;
-	int lzuerror;
+	lzma_ret lzuerror;
 
 	ACQUIRE_LOCK(self);
 	if(!self->open){
@@ -512,7 +512,7 @@ LZMAFile_seek(LZMAFileObject *self, PyObject *args)
 	Py_off_t bytesread = 0;
 	size_t readsize;
 	int chunksize;
-	int lzuerror;
+	lzma_ret lzuerror;
 	PyObject *ret = NULL;
 
 	if (!PyArg_ParseTuple(args, "O|i:seek", &offobj, &where))
@@ -675,7 +675,7 @@ static PyObject *
 LZMAFile_close(LZMAFileObject *self)
 {
 	PyObject *ret = NULL;
-	int lzuerror = LZMA_OK;
+	lzma_ret lzuerror = LZMA_OK;
 
 	ACQUIRE_LOCK(self);
 	if(self->open) {
@@ -825,7 +825,8 @@ LZMAFile_init(LZMAFileObject *self, PyObject *args, PyObject *kwargs)
 			case 'w':
 				if(!options)
 				{
-					lzma_options_lzma _options = lzma_preset_lzma[LZMA_DEFAULT_COMPRESSION-1];
+					lzma_options_lzma _options;
+					lzma_lzma_preset(&_options, LZMA_DEFAULT_COMPRESSION-1);
 					if(!init_lzma_options("LZMAFile", kwargs, &_options))
 						return -1;
 					options = &_options;
