@@ -34,7 +34,7 @@ typedef struct {
 	bool f_skipnextlf;	/* Skip next \n */
 
 	lzma_FILE *fp;
-	lzma_options_alone alone;
+	lzma_options_lzma options;
 
 	bool open;
 	Py_off_t pos;
