@@ -8,7 +8,7 @@ different min and max value constants for these in the variables.\n\
 
 static PyMemberDef LZMAOptions_members[12];
 
-static PyObject *mode, *match_finder, *format;
+static PyObject *mode, *mf, *format;
 
 static PyObject *
 LZMAOptions_repr(LZMAOptionsObject *obj)
@@ -21,30 +21,30 @@ LZMAOptions_dealloc(LZMAOptionsObject* self)
 {
 	Py_XDECREF(self->eopm);
 	Py_XDECREF(self->level);
-	Py_XDECREF(self->dictionary_size);
-	Py_XDECREF(self->literal_context_bits);
-	Py_XDECREF(self->literal_pos_bits);
-	Py_XDECREF(self->pos_bits);
+	Py_XDECREF(self->dict_size);
+	Py_XDECREF(self->lc);
+	Py_XDECREF(self->lp);
+	Py_XDECREF(self->pb);
 	Py_XDECREF(self->mode_dict);
 	Py_XDECREF(self->mode);
-	Py_XDECREF(self->fast_bytes);
-	Py_XDECREF(self->match_finder_dict);
-	Py_XDECREF(self->match_finder);
-	Py_XDECREF(self->match_finder_cycles);
+	Py_XDECREF(self->nice_len);
+	Py_XDECREF(self->mf_dict);
+	Py_XDECREF(self->mf);
+	Py_XDECREF(self->depth);
 	self->ob_type->tp_free((PyObject*)self);
 }
 
 PyObject *
 LZMA_options_get(lzma_options_lzma lzma_options){
 	PyObject * options = PyDict_New();
-	PyMapping_SetItemString(options, "dictionary_size", PyInt_FromLong((long)lzma_options.dictionary_size));
-	PyMapping_SetItemString(options, "literal_context_bits", PyInt_FromLong((long)lzma_options.literal_context_bits));
-	PyMapping_SetItemString(options, "literal_pos_bits", PyInt_FromLong((long)lzma_options.literal_pos_bits));
-	PyMapping_SetItemString(options, "pos_bits", PyInt_FromLong((long)lzma_options.pos_bits));
+	PyMapping_SetItemString(options, "dict_size", PyInt_FromLong((long)lzma_options.dict_size));
+	PyMapping_SetItemString(options, "lc", PyInt_FromLong((long)lzma_options.lc));
+	PyMapping_SetItemString(options, "lp", PyInt_FromLong((long)lzma_options.lp));
+	PyMapping_SetItemString(options, "pb", PyInt_FromLong((long)lzma_options.pb));
 	PyMapping_SetItemString(options, "mode", PyDict_GetItem(mode, PyInt_FromLong((long)lzma_options.mode)));
-	PyMapping_SetItemString(options, "fast_bytes", PyInt_FromLong((long)lzma_options.fast_bytes));
-	PyMapping_SetItemString(options, "match_finder", PyDict_GetItem(match_finder, PyInt_FromLong((long)lzma_options.match_finder)));
-	PyMapping_SetItemString(options, "match_finder_cycles", PyInt_FromLong((long)lzma_options.match_finder_cycles));
+	PyMapping_SetItemString(options, "nice_len", PyInt_FromLong((long)lzma_options.nice_len));
+	PyMapping_SetItemString(options, "mf", PyDict_GetItem(mf, PyInt_FromLong((long)lzma_options.mf)));
+	PyMapping_SetItemString(options, "depth", PyInt_FromLong((long)lzma_options.depth));
 	return options;
 }
 
@@ -57,9 +57,9 @@ init_lzma_options(const char *funcName, PyObject *kwargs, lzma_options_lzma *opt
 	const char *argtypes = "|iiiiiiOO:";
 	PyObject *args;
 	char argstring[strlen(argtypes)+strlen(funcName)+2];
-    	static char *kwlist[] = {"dictionary_size",
-		"literal_context_bits", "literal_pos_bits", "pos_bits", "fast_bytes",
-		"match_finder_cycles", "mode", "match_finder", 0};
+    	static char *kwlist[] = {"dict_size",
+		"lc", "lp", "pb", "nice_len",
+		"depth", "mode", "mf", NULL};
 	PyObject *mf_key = NULL, *mode_key = NULL;
 
 	if(kwargs != NULL){
@@ -67,8 +67,8 @@ init_lzma_options(const char *funcName, PyObject *kwargs, lzma_options_lzma *opt
 		if(PyDict_Contains(kwargs, levelString)){
 			uint8_t level =  (uint8_t)PyInt_AsLong(PyDict_GetItem(kwargs, levelString));
 			PyDict_DelItem(kwargs, levelString);
-			CHECK_RANGE(level--, LZMA_BEST_SPEED, LZMA_BEST_COMPRESSION, "compression level must be between %d and %d, got %d");
-			*options = lzma_preset_lzma[level];
+			CHECK_RANGE(level, LZMA_BEST_SPEED, LZMA_BEST_COMPRESSION, "compression level must be between %d and %d, got %d");
+			lzma_lzma_preset(options, level);
 		}
 	}
 
@@ -93,23 +93,22 @@ init_lzma_options(const char *funcName, PyObject *kwargs, lzma_options_lzma *opt
 	args = PyTuple_New(0);
 	snprintf(argstring, strlen(argtypes)+strlen(funcName)+2, "%s%s\n", argtypes, funcName);
 	if (!PyArg_ParseTupleAndKeywords(args, kwargs, argstring, kwlist,
-				&options->dictionary_size, &options->literal_context_bits,
-				&options->literal_pos_bits, &options->pos_bits,	&options->fast_bytes,
-				&options->match_finder_cycles, &mode_key, &mf_key))
+				&options->dict_size, &options->lc, &options->lp, &options->pb,
+				&options->nice_len, &options->depth, &mode_key, &mf_key))
 		return false;
 	Py_XDECREF(args);
-	CHECK_RANGE(options->dictionary_size, LZMA_DICTIONARY_SIZE_MIN,
-			LZMA_DICTIONARY_SIZE_MAX, "dictionary_size must be between %d and %d, got %d");
-    	CHECK_RANGE(options->literal_context_bits, LZMA_LITERAL_CONTEXT_BITS_MIN,
-			LZMA_LITERAL_CONTEXT_BITS_MAX, "literal_context_bits must be between %d and %d, got %d");
-    	CHECK_RANGE(options->literal_pos_bits, LZMA_POS_BITS_MIN, LZMA_POS_BITS_MAX,
-		       	"literal_pos_bits must be between %d and %d, got %d");
-    	CHECK_RANGE(options->pos_bits, LZMA_POS_BITS_MIN, LZMA_POS_BITS_MAX,
-		       	"pos_bits must be between %d and %d, got %d");
-    	CHECK_RANGE(options->fast_bytes, LZMA_FAST_BYTES_MIN, LZMA_FAST_BYTES_MAX,
+	CHECK_RANGE(options->dict_size, LZMA_DICT_SIZE_MIN, LZMA_DICT_SIZE_MAX,
+			"dict_size must be between %d and %d, got %d");
+    	CHECK_RANGE(options->lc, LZMA_LCLP_MIN, LZMA_LCLP_MAX,
+			"lc must be between %d and %d, got %d");
+    	CHECK_RANGE(options->lp, LZMA_LCLP_MIN, LZMA_LCLP_MAX,
+		       	"lp must be between %d and %d, got %d");
+    	CHECK_RANGE(options->pb, LZMA_PB_MIN, LZMA_PB_MAX,
+		       	"pb must be between %d and %d, got %d");
+    	CHECK_RANGE(options->nice_len, LZMA_NICE_LEN_MIN, LZMA_NICE_LEN_MAX,
 		       	"fast_bytes must be between %d and %d, got %d");
-	if((int)options->match_finder_cycles < 0){
-		PyErr_Format(PyExc_ValueError, "match_finder_cycles must be >= 0");
+	if((int)options->depth < 0){
+		PyErr_Format(PyExc_ValueError, "depth must be >= 0");
 		return false;
 	}
 
@@ -136,7 +135,7 @@ init_lzma_options(const char *funcName, PyObject *kwargs, lzma_options_lzma *opt
 	Py_XDECREF(mode_key);
 	switch(options->mode){
 		case(LZMA_MODE_FAST):
-		case(LZMA_MODE_BEST):
+		case(LZMA_MODE_NORMAL):
 			break;
 		case(LZMA_MODE_INVALID):
 		default:
@@ -148,25 +147,25 @@ init_lzma_options(const char *funcName, PyObject *kwargs, lzma_options_lzma *opt
 	}
 
 	if(mf_key){
-		options->match_finder = LZMA_MF_INVALID;
+		options->mf = LZMA_MF_INVALID;
 		if(PyInt_Check(mf_key))
-			options->match_finder = PyInt_AsLong(mf_key);
-		else if(PyString_Check(mf_key) && PyDict_Contains(match_finder, mf_key))
-			options->match_finder = PyInt_AsLong(PyDict_GetItem(match_finder, mf_key));
+			options->mf = PyInt_AsLong(mf_key);
+		else if(PyString_Check(mf_key) && PyDict_Contains(mf, mf_key))
+			options->mf = PyInt_AsLong(PyDict_GetItem(mf, mf_key));
 		else if(PyString_Check(mf_key)){
 			PyObject *key, *value;
 			Py_ssize_t pos = 0;
 			
-			while (PyDict_Next(match_finder, &pos, &key, &value)) {
+			while (PyDict_Next(mf, &pos, &key, &value)) {
 				if(PyObject_RichCompareBool(mf_key,value,Py_EQ)){
-					options->match_finder = PyInt_AsLong(key);
+					options->mf = PyInt_AsLong(key);
 					break;
 				}
 			}
 		}
 	}
 	Py_XDECREF(mf_key);
-	switch(options->match_finder){
+	switch(options->mf){
 		case(LZMA_MF_HC3):
 		case(LZMA_MF_HC4):
 		case(LZMA_MF_BT2):
@@ -177,8 +176,8 @@ init_lzma_options(const char *funcName, PyObject *kwargs, lzma_options_lzma *opt
 		default:
 			PyErr_SetObject(PyExc_ValueError,
 					PyString_Format(PyString_FromString(
-					"match_finder must be either '%s', '%s', '%s', '%s' or '%s'"),
-					PyList_AsTuple(PyDict_Values(match_finder))));
+					"mf must be either '%s', '%s', '%s', '%s' or '%s'"),
+					PyList_AsTuple(PyDict_Values(mf))));
 			return false;
 	}
 	return true;
@@ -196,42 +195,42 @@ LZMAOptions_alloc(PyTypeObject *type, Py_ssize_t nitems)
 	self->eopm = PyTuple_Pack(2, Py_False, Py_True);
 	self->level = PyTuple_Pack(2, PyInt_FromLong((ulong)LZMA_BEST_SPEED),
 			PyInt_FromLong((ulong)LZMA_BEST_COMPRESSION));
-	self->dictionary_size = PyTuple_Pack(2, PyInt_FromLong((ulong)LZMA_DICTIONARY_SIZE_MIN),
-			PyInt_FromLong((ulong)LZMA_DICTIONARY_SIZE_MAX));
-	self->literal_context_bits = PyTuple_Pack(2, PyInt_FromLong((ulong)LZMA_LITERAL_CONTEXT_BITS_MIN),
-			PyInt_FromLong((ulong)LZMA_LITERAL_CONTEXT_BITS_MAX));
-	self->literal_pos_bits = PyTuple_Pack(2, PyInt_FromLong((ulong)LZMA_LITERAL_POS_BITS_MIN),
-			PyInt_FromLong((ulong)LZMA_LITERAL_POS_BITS_MAX));
-	self->pos_bits = PyTuple_Pack(2, PyInt_FromLong((ulong)LZMA_POS_BITS_MIN),
-			PyInt_FromLong((ulong)LZMA_POS_BITS_MAX));
+	self->dict_size = PyTuple_Pack(2, PyInt_FromLong((ulong)LZMA_DICT_SIZE_MIN),
+			PyInt_FromLong((ulong)LZMA_DICT_SIZE_MAX));
+	self->lc = PyTuple_Pack(2, PyInt_FromLong((ulong)LZMA_LCLP_MIN),
+			PyInt_FromLong((ulong)LZMA_LCLP_MAX));
+	self->lp = PyTuple_Pack(2, PyInt_FromLong((ulong)LZMA_LCLP_MIN),
+			PyInt_FromLong((ulong)LZMA_LCLP_MAX));
+	self->pb = PyTuple_Pack(2, PyInt_FromLong((ulong)LZMA_PB_MIN),
+			PyInt_FromLong((ulong)LZMA_PB_MAX));
 	self->mode_dict = PyDict_New();
-	self->fast_bytes = PyTuple_Pack(2, PyInt_FromLong((ulong)LZMA_FAST_BYTES_MIN),
-		       	PyInt_FromLong((ulong)LZMA_FAST_BYTES_MAX));
-	self->match_finder_dict = PyDict_New();
-	self->match_finder_cycles = PyInt_FromLong(0);
+	self->nice_len = PyTuple_Pack(2, PyInt_FromLong((ulong)LZMA_NICE_LEN_MIN),
+		       	PyInt_FromLong((ulong)LZMA_NICE_LEN_MAX));
+	self->mf_dict = PyDict_New();
+	self->depth = PyInt_FromLong(0);
 
 	PyDict_SetItem(self->mode_dict, PyInt_FromLong((ulong)LZMA_MODE_FAST),
 			PyString_FromString("fast"));
-	PyDict_SetItem(self->mode_dict, PyInt_FromLong((ulong)LZMA_MODE_BEST),
+	PyDict_SetItem(self->mode_dict, PyInt_FromLong((ulong)LZMA_MODE_NORMAL),
 			PyString_FromString("best"));
 	mode = self->mode_dict;
 
 	self->mode = PyList_AsTuple(PyDict_Values(self->mode_dict));
-	PyDict_SetItem(self->match_finder_dict, PyInt_FromLong((ulong)LZMA_MF_HC3),
+	PyDict_SetItem(self->mf_dict, PyInt_FromLong((ulong)LZMA_MF_HC3),
 			PyString_FromString("hc3"));
-	PyDict_SetItem(self->match_finder_dict, PyInt_FromLong((ulong)LZMA_MF_HC4),
+	PyDict_SetItem(self->mf_dict, PyInt_FromLong((ulong)LZMA_MF_HC4),
 			PyString_FromString("hc4"));
-	PyDict_SetItem(self->match_finder_dict, PyInt_FromLong((ulong)LZMA_MF_BT2),
+	PyDict_SetItem(self->mf_dict, PyInt_FromLong((ulong)LZMA_MF_BT2),
 			PyString_FromString("bt2"));
-	PyDict_SetItem(self->match_finder_dict, PyInt_FromLong((ulong)LZMA_MF_BT3),
+	PyDict_SetItem(self->mf_dict, PyInt_FromLong((ulong)LZMA_MF_BT3),
 			PyString_FromString("bt3"));
-	PyDict_SetItem(self->match_finder_dict, PyInt_FromLong((ulong)LZMA_MF_BT4),
+	PyDict_SetItem(self->mf_dict, PyInt_FromLong((ulong)LZMA_MF_BT4),
 			PyString_FromString("bt4"));
-	mf_list = PyDict_Values(self->match_finder_dict);
+	mf_list = PyDict_Values(self->mf_dict);
 	PyList_Sort(mf_list);
-	self->match_finder =  PyList_AsTuple(mf_list);
+	self->mf =  PyList_AsTuple(mf_list);
 	Py_DECREF(mf_list);
-	match_finder = self->match_finder_dict;
+	mf = self->mf_dict;
 	Py_INCREF(self);
 
 	LZMAOptions_members[0] = MEMBER_DESCRIPTOR("eopm", T_OBJECT, eopm,
@@ -252,8 +251,10 @@ level\t lc\t lp\t dict\t\t pb\t mode\t mf\t fb\t mfc\n");
 	
 	{off_t i;
 	for(i = LZMA_BEST_COMPRESSION; i >= LZMA_BEST_SPEED; i--){
+		lzma_options_lzma options;
+		lzma_lzma_preset(&options, i-1);
 		PyObject *settingsString = PyString_Format(levelopts,
-			       	PyList_AsTuple(PyDict_Values(LZMA_options_get(lzma_preset_lzma[i-1]))));
+			       	PyList_AsTuple(PyDict_Values(LZMA_options_get(options))));
 		PyObject *levelNum = PyString_Format(settingsString, PyInt_FromLong(i));
 		PyString_Concat(&levelString,levelNum);
 		Py_DECREF(settingsString);
@@ -263,25 +264,30 @@ level\t lc\t lp\t dict\t\t pb\t mode\t mf\t fb\t mfc\n");
 
 	LZMAOptions_members[1] = MEMBER_DESCRIPTOR("level", T_OBJECT, level, PyString_AsString(levelString));
 	Py_DECREF(levelString);
-	LZMAOptions_members[2] = MEMBER_DESCRIPTOR("dictionary_size", T_OBJECT, dictionary_size,
+	LZMAOptions_members[2] = MEMBER_DESCRIPTOR("dict_size", T_OBJECT, dict_size,
 "Dictionary size in bytes (%u - %u)\n\
 Dictionary size indicates how many bytes of the recently processed\n\
 uncompressed data is kept in memory. One method to reduce size of\n\
 the uncompressed data is to store distance-length pairs, which\n\
 indicate what data to repeat from the dictionary buffer. Thus,\n\
 the bigger the dictionary, the better compression ratio usually is.\n");
-	LZMAOptions_members[3] = MEMBER_DESCRIPTOR("literal_context_bits", T_OBJECT, literal_context_bits,
+	LZMAOptions_members[3] = MEMBER_DESCRIPTOR("lc", T_OBJECT, lc,
 "Number of literal context bits (%u - %u)\n\
 How many of the highest bits of the previous uncompressed\n\
 eight-bit byte (also known as `literal') are taken into\n\
-account when predicting the bits of the next literal.\n");
-	LZMAOptions_members[4] = MEMBER_DESCRIPTOR("literal_pos_bits", T_OBJECT, literal_pos_bits,
+account when predicting the bits of the next literal.\n\
+\n\
+There is a limit that applies to literal context bits and literal\n\
+position bits together: lc + lp <= 4. Without this limit the\n\
+decoding could become very slow, which could have security related\n\
+results in some cases like email servers doing virus scanning.");
+	LZMAOptions_members[4] = MEMBER_DESCRIPTOR("lp", T_OBJECT, lp,
 "Number of literal position bits (%u - %u)\n\
 How many of the lowest bits of the current position (number\n\
 of bytes from the beginning of the uncompressed data) in the\n\
 uncompressed data is taken into account when predicting the\n\
 bits of the next literal (a single eight-bit byte).\n");
-	LZMAOptions_members[5] = MEMBER_DESCRIPTOR("pos_bits", T_OBJECT, pos_bits,
+	LZMAOptions_members[5] = MEMBER_DESCRIPTOR("pb", T_OBJECT, pb,
 "Number of position bits Position bits (%u - %u)\n\
 How many of the lowest bits of the current position in the\n\
 uncompressed data is taken into account when estimating\n\
@@ -297,27 +303,27 @@ because 2**3 == 8.\n");
 Fast mode is usually at its best when combined with a hash chain match finder.\n\
 Best is usually notably slower than fast mode. Use this together with binary\n\
 tree match finders to expose the full potential of the LZMA encoder.");
-	LZMAOptions_members[7] = MEMBER_DESCRIPTOR("fast_bytes", T_OBJECT, fast_bytes,
-"Number of fast bytes (%u - %u)\n\
-Number of fast bytes determines how many bytes the encoder\n\
+	LZMAOptions_members[7] = MEMBER_DESCRIPTOR("nice_len", T_OBJECT, nice_len,
+"Nice lengt of a match (also known as number of fast bytes) (%u - %u)\n\
+Nice length of match determines how many bytes the encoder\n\
 compares from the match candidates when looking for the best\n\
 match. Bigger fast bytes value usually increase both compression\n\
 ratio and time.\n");
-	LZMAOptions_members[8] = MEMBER_DESCRIPTOR("match_finder", T_OBJECT, match_finder,
+	LZMAOptions_members[8] = MEMBER_DESCRIPTOR("mf", T_OBJECT, mf,
 "Match finder has major effect on both speed and compression ratio.\n\
 Usually hash chains are faster than binary trees.\n\
 Available match finders:\n\
 '%s': Binary Tree with 2 bytes hashing\n\
-       Memory requirements: 9.5 * dictionary_size + 4 MiB\n\
+       Memory requirements: 9.5 * dict_size + 4 MiB\n\
 '%s': Binary Tree with 3 bytes hashing\n\
-       Memory requirements: 11.5 * dictionary_size + 4 MiB\n\
+       Memory requirements: 11.5 * dict_size + 4 MiB\n\
 '%s': Binary Tree with 4 bytes hashing\n\
-       Memory requirements: 11.5 * dictionary_size + 4 MiB\n\
+       Memory requirements: 11.5 * dict_size + 4 MiB\n\
 '%s': Hash Chain with 3 bytes hashing\n\
 '%s': Hash Chain with 4 bytes hashing\n\
-       Memory requirements: 7.5 * dictionary_size + 4 MiB\n");
-	LZMAOptions_members[9] = MEMBER_DESCRIPTOR("match_finder_cycles", T_INT, match_finder_cycles,
-"Match finder cycles\n\
+       Memory requirements: 7.5 * dict_size + 4 MiB\n");
+	LZMAOptions_members[9] = MEMBER_DESCRIPTOR("depth", T_INT, depth,
+"Depth (also known as match finder cycles)\n\
 Higher values give slightly better compression ratio but\n\
 decrease speed. Use special value %u to let liblzma use\n\
 match-finder-dependent default value.\n");
