@@ -10,12 +10,19 @@ static inline bool check_range(uint32_t x, uint32_t a, uint32_t b){
 }
 #define MEMBER_DESCRIPTOR(name, type, variable, text) (PyMemberDef){name, type, offsetof(LZMAOptionsObject, variable), RO, PyString_AsString(PyString_Format(PyString_FromString((char*)text), (PyObject*)self->variable))}
 
-#define	LZMA_BEST_SPEED 1
-#define	LZMA_BEST_COMPRESSION 9
-#define	LZMA_DEFAULT_COMPRESSION 7
-#define	LZMA_MODE_DEFAULT LZMA_MODE_BEST
-#define	LZMA_MF_DEFAULT	LZMA_MF_BT4
-#define	LZMA_MF_CYCLES_DEFAULT 0
+#define	LZMA_BEST_SPEED			1
+#define	LZMA_BEST_COMPRESSION		9
+#define	LZMA_DEFAULT_COMPRESSION	7
+#define	LZMA_MODE_DEFAULT		LZMA_MODE_NORMAL
+#define LZMA_MODE_INVALID		-1
+#define LZMA_MF_INVALID			-1
+
+#define	LZMA_MF_DEFAULT			LZMA_MF_BT4
+#define	LZMA_MF_CYCLES_DEFAULT		0
+#define LZMA_DICT_SIZE_MAX 		(UINT32_C(1) << 30) + (UINT32_C(1) << 29)
+#define LZMA_NICE_LEN_MIN		5
+#define LZMA_NICE_LEN_MAX		273
+#define LZMA_NICE_LEN_DEFAULT		128
 
 typedef struct
 {
@@ -23,16 +30,16 @@ typedef struct
 	PyObject *format;
 	PyObject *eopm;
 	PyObject *level;
-	PyObject *dictionary_size;
-	PyObject *literal_context_bits;
-	PyObject *literal_pos_bits;
-	PyObject *pos_bits;
+	PyObject *dict_size;
+	PyObject *lc;
+	PyObject *lp;
+	PyObject *pb;
 	PyObject *mode_dict;
 	PyObject *mode;
-	PyObject *fast_bytes;
-	PyObject *match_finder_dict;
-	PyObject *match_finder;
-	PyObject *match_finder_cycles;
+	PyObject *nice_len;
+	PyObject *mf_dict;
+	PyObject *mf;
+	PyObject *depth;
 } LZMAOptionsObject;
 
 extern PyTypeObject LZMAOptions_Type;
